@@ -22,7 +22,8 @@ smtp_port_gmail = 587
 smtp_server_qq = 'smtp.qq.com'
 smtp_port_qq = 465
 
-pop3_server=''
+pop3_server_gmail='pop.gmail.com'
+pop3_server_qq='pop.qq.com'
 
 def _format_addr(s):
     name, addr = parseaddr(s)
@@ -261,14 +262,14 @@ def _get_email_info(msg, func,indent=0):
 
 
 
-def receive_email(account,password,recive_data_func):
+def receive_email_gmail(account,password,recive_data_func):
     if not callable(recive_data_func):
         raise AttributeError("The parameter is incorrect and a function that accepts data is required.")
-    server = poplib.POP3(pop3_server)
+    server = poplib.POP3_SSL(pop3_server_gmail)
     # server.set_debuglevel(1)
     recive_data_func(server.getwelcome())
     # 认证:
-    server.user(email)
+    server.user(account)
     server.pass_(password)
     recive_data_func('Messages: %s. Size: %s' % server.stat())
     resp, mails, octets = server.list()
@@ -284,4 +285,25 @@ def receive_email(account,password,recive_data_func):
     server.quit()
 
 
-print callable(receive_email)
\ No newline at end of file
+
+def receive_email_qq(account,password,recive_data_func):
+    if not callable(recive_data_func):
+        raise AttributeError("The parameter is incorrect and a function that accepts data is required.")
+    server = poplib.POP3_SSL(pop3_server_qq)
+    # server.set_debuglevel(1)
+    recive_data_func(server.getwelcome())
+    # 认证:
+    server.user(account)
+    server.pass_(password)
+    recive_data_func('Messages: %s. Size: %s' % server.stat())
+    resp, mails, octets = server.list()
+    # 获取最新一封邮件, 注意索引号从1开始:
+    resp, lines, octets = server.retr(len(mails))
+    # 解析邮件:
+    msg = Parser().parsestr('\r\n'.join(lines))
+    # 打印邮件内容:
+    _get_email_info(msg,recive_data_func)
+    # 慎重:将直接从服务器删除邮件:
+    # server.dele(len(mails))
+    # 关闭连接:
+    server.quit()
